<a id="types-aiobotocore-securityhub"></a>

# types-aiobotocore-securityhub

[![PyPI - types-aiobotocore-securityhub](https://img.shields.io/pypi/v/types-aiobotocore-securityhub.svg?color=blue)](https://pypi.org/project/types-aiobotocore-securityhub)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-securityhub.svg?color=blue)](https://pypi.org/project/types-aiobotocore-securityhub)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-securityhub?color=blue)](https://pypistats.org/packages/types-aiobotocore-securityhub)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.SecurityHub 2.4.2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/securityhub.html#SecurityHub)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.12.5](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-securityhub docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securityhub/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-securityhub](#types-aiobotocore-securityhub)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `SecurityHub` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[securityhub]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[securityhub]'


# standalone installation
python -m pip install types-aiobotocore-securityhub
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-securityhub
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[securityhub]` in your environment:

```bash
python -m pip install 'types-aiobotocore[securityhub]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[securityhub]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[securityhub]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[securityhub]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[securityhub]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[securityhub]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[securityhub]` in your environment:

```bash
python -m pip install 'types-aiobotocore[securityhub]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[securityhub]` in your environment:

```bash
python -m pip install 'types-aiobotocore[securityhub]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`SecurityHubClient` provides annotations for
`session.create_client("securityhub")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_securityhub import SecurityHubClient

session = get_session()
async with session.create_client("securityhub") as client:
    client: SecurityHubClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_securityhub.paginator` module contains type annotations for
all paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_securityhub import SecurityHubClient
from types_aiobotocore_securityhub.paginator import (
    DescribeActionTargetsPaginator,
    DescribeProductsPaginator,
    DescribeStandardsPaginator,
    DescribeStandardsControlsPaginator,
    GetEnabledStandardsPaginator,
    GetFindingsPaginator,
    GetInsightsPaginator,
    ListEnabledProductsForImportPaginator,
    ListFindingAggregatorsPaginator,
    ListInvitationsPaginator,
    ListMembersPaginator,
    ListOrganizationAdminAccountsPaginator,
)

session = get_session()
async with session.create_client("securityhub") as client:
    client: SecurityHubClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_action_targets_paginator: DescribeActionTargetsPaginator = client.get_paginator(
        "describe_action_targets"
    )
    describe_products_paginator: DescribeProductsPaginator = client.get_paginator(
        "describe_products"
    )
    describe_standards_paginator: DescribeStandardsPaginator = client.get_paginator(
        "describe_standards"
    )
    describe_standards_controls_paginator: DescribeStandardsControlsPaginator = (
        client.get_paginator("describe_standards_controls")
    )
    get_enabled_standards_paginator: GetEnabledStandardsPaginator = client.get_paginator(
        "get_enabled_standards"
    )
    get_findings_paginator: GetFindingsPaginator = client.get_paginator("get_findings")
    get_insights_paginator: GetInsightsPaginator = client.get_paginator("get_insights")
    list_enabled_products_for_import_paginator: ListEnabledProductsForImportPaginator = (
        client.get_paginator("list_enabled_products_for_import")
    )
    list_finding_aggregators_paginator: ListFindingAggregatorsPaginator = client.get_paginator(
        "list_finding_aggregators"
    )
    list_invitations_paginator: ListInvitationsPaginator = client.get_paginator("list_invitations")
    list_members_paginator: ListMembersPaginator = client.get_paginator("list_members")
    list_organization_admin_accounts_paginator: ListOrganizationAdminAccountsPaginator = (
        client.get_paginator("list_organization_admin_accounts")
    )
```

<a id="literals"></a>

### Literals

`types_aiobotocore_securityhub.literals` module contains literals extracted
from shapes that can be used in user code for type checking.

```python
from types_aiobotocore_securityhub.literals import (
    AdminStatusType,
    AutoEnableStandardsType,
    AwsIamAccessKeyStatusType,
    AwsS3BucketNotificationConfigurationS3KeyFilterRuleNameType,
    ComplianceStatusType,
    ControlStatusType,
    DateRangeUnitType,
    DescribeActionTargetsPaginatorName,
    DescribeProductsPaginatorName,
    DescribeStandardsControlsPaginatorName,
    DescribeStandardsPaginatorName,
    GetEnabledStandardsPaginatorName,
    GetFindingsPaginatorName,
    GetInsightsPaginatorName,
    IntegrationTypeType,
    ListEnabledProductsForImportPaginatorName,
    ListFindingAggregatorsPaginatorName,
    ListInvitationsPaginatorName,
    ListMembersPaginatorName,
    ListOrganizationAdminAccountsPaginatorName,
    MalwareStateType,
    MalwareTypeType,
    MapFilterComparisonType,
    NetworkDirectionType,
    PartitionType,
    RecordStateType,
    SeverityLabelType,
    SeverityRatingType,
    SortOrderType,
    StandardsStatusType,
    StatusReasonCodeType,
    StringFilterComparisonType,
    ThreatIntelIndicatorCategoryType,
    ThreatIntelIndicatorTypeType,
    VerificationStateType,
    VulnerabilityFixAvailableType,
    WorkflowStateType,
    WorkflowStatusType,
    SecurityHubServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AdminStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_securityhub.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_securityhub.type_defs import (
    AcceptAdministratorInvitationRequestRequestTypeDef,
    AcceptInvitationRequestRequestTypeDef,
    AccountDetailsTypeDef,
    ActionLocalIpDetailsTypeDef,
    ActionLocalPortDetailsTypeDef,
    CityTypeDef,
    CountryTypeDef,
    GeoLocationTypeDef,
    IpOrganizationDetailsTypeDef,
    ActionRemotePortDetailsTypeDef,
    ActionTargetTypeDef,
    DnsRequestActionTypeDef,
    AdjustmentTypeDef,
    AdminAccountTypeDef,
    AvailabilityZoneTypeDef,
    AwsApiCallActionDomainDetailsTypeDef,
    AwsApiGatewayAccessLogSettingsTypeDef,
    AwsApiGatewayCanarySettingsTypeDef,
    AwsApiGatewayEndpointConfigurationTypeDef,
    AwsApiGatewayMethodSettingsTypeDef,
    AwsCorsConfigurationTypeDef,
    AwsApiGatewayV2RouteSettingsTypeDef,
    AwsAutoScalingAutoScalingGroupAvailabilityZonesListDetailsTypeDef,
    AwsAutoScalingAutoScalingGroupLaunchTemplateLaunchTemplateSpecificationTypeDef,
    AwsAutoScalingAutoScalingGroupMixedInstancesPolicyInstancesDistributionDetailsTypeDef,
    AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecificationTypeDef,
    AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateOverridesListDetailsTypeDef,
    AwsAutoScalingLaunchConfigurationBlockDeviceMappingsEbsDetailsTypeDef,
    AwsAutoScalingLaunchConfigurationInstanceMonitoringDetailsTypeDef,
    AwsAutoScalingLaunchConfigurationMetadataOptionsTypeDef,
    AwsBackupBackupPlanAdvancedBackupSettingsDetailsTypeDef,
    AwsBackupBackupPlanLifecycleDetailsTypeDef,
    AwsBackupBackupVaultNotificationsDetailsTypeDef,
    AwsBackupRecoveryPointCalculatedLifecycleDetailsTypeDef,
    AwsBackupRecoveryPointCreatedByDetailsTypeDef,
    AwsBackupRecoveryPointLifecycleDetailsTypeDef,
    AwsCertificateManagerCertificateExtendedKeyUsageTypeDef,
    AwsCertificateManagerCertificateKeyUsageTypeDef,
    AwsCertificateManagerCertificateOptionsTypeDef,
    AwsCertificateManagerCertificateResourceRecordTypeDef,
    AwsCloudFormationStackDriftInformationDetailsTypeDef,
    AwsCloudFormationStackOutputsDetailsTypeDef,
    AwsCloudFrontDistributionCacheBehaviorTypeDef,
    AwsCloudFrontDistributionDefaultCacheBehaviorTypeDef,
    AwsCloudFrontDistributionLoggingTypeDef,
    AwsCloudFrontDistributionViewerCertificateTypeDef,
    AwsCloudFrontDistributionOriginSslProtocolsTypeDef,
    AwsCloudFrontDistributionOriginGroupFailoverStatusCodesTypeDef,
    AwsCloudFrontDistributionOriginS3OriginConfigTypeDef,
    AwsCloudTrailTrailDetailsTypeDef,
    AwsCloudWatchAlarmDimensionsDetailsTypeDef,
    AwsCodeBuildProjectArtifactsDetailsTypeDef,
    AwsCodeBuildProjectSourceTypeDef,
    AwsCodeBuildProjectVpcConfigTypeDef,
    AwsCodeBuildProjectEnvironmentEnvironmentVariablesDetailsTypeDef,
    AwsCodeBuildProjectEnvironmentRegistryCredentialTypeDef,
    AwsCodeBuildProjectLogsConfigCloudWatchLogsDetailsTypeDef,
    AwsCodeBuildProjectLogsConfigS3LogsDetailsTypeDef,
    AwsDynamoDbTableAttributeDefinitionTypeDef,
    AwsDynamoDbTableBillingModeSummaryTypeDef,
    AwsDynamoDbTableKeySchemaTypeDef,
    AwsDynamoDbTableProvisionedThroughputTypeDef,
    AwsDynamoDbTableRestoreSummaryTypeDef,
    AwsDynamoDbTableSseDescriptionTypeDef,
    AwsDynamoDbTableStreamSpecificationTypeDef,
    AwsDynamoDbTableProjectionTypeDef,
    AwsDynamoDbTableProvisionedThroughputOverrideTypeDef,
    AwsEc2EipDetailsTypeDef,
    AwsEc2InstanceMetadataOptionsTypeDef,
    AwsEc2InstanceNetworkInterfacesDetailsTypeDef,
    AwsEc2NetworkAclAssociationTypeDef,
    IcmpTypeCodeTypeDef,
    PortRangeFromToTypeDef,
    AwsEc2NetworkInterfaceAttachmentTypeDef,
    AwsEc2NetworkInterfaceIpV6AddressDetailTypeDef,
    AwsEc2NetworkInterfacePrivateIpAddressDetailTypeDef,
    AwsEc2NetworkInterfaceSecurityGroupTypeDef,
    AwsEc2SecurityGroupIpRangeTypeDef,
    AwsEc2SecurityGroupIpv6RangeTypeDef,
    AwsEc2SecurityGroupPrefixListIdTypeDef,
    AwsEc2SecurityGroupUserIdGroupPairTypeDef,
    Ipv6CidrBlockAssociationTypeDef,
    AwsEc2TransitGatewayDetailsTypeDef,
    AwsEc2VolumeAttachmentTypeDef,
    CidrBlockAssociationTypeDef,
    AwsEc2VpcEndpointServiceServiceTypeDetailsTypeDef,
    AwsEc2VpcPeeringConnectionStatusDetailsTypeDef,
    VpcInfoCidrBlockSetDetailsTypeDef,
    VpcInfoIpv6CidrBlockSetDetailsTypeDef,
    VpcInfoPeeringOptionsDetailsTypeDef,
    AwsEc2VpnConnectionRoutesDetailsTypeDef,
    AwsEc2VpnConnectionVgwTelemetryDetailsTypeDef,
    AwsEc2VpnConnectionOptionsTunnelOptionsDetailsTypeDef,
    AwsEcrContainerImageDetailsTypeDef,
    AwsEcrRepositoryImageScanningConfigurationDetailsTypeDef,
    AwsEcrRepositoryLifecyclePolicyDetailsTypeDef,
    AwsEcsClusterClusterSettingsDetailsTypeDef,
    AwsEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationDetailsTypeDef,
    AwsEcsClusterDefaultCapacityProviderStrategyDetailsTypeDef,
    AwsMountPointTypeDef,
    AwsEcsServiceCapacityProviderStrategyDetailsTypeDef,
    AwsEcsServiceDeploymentConfigurationDeploymentCircuitBreakerDetailsTypeDef,
    AwsEcsServiceDeploymentControllerDetailsTypeDef,
    AwsEcsServiceLoadBalancersDetailsTypeDef,
    AwsEcsServicePlacementConstraintsDetailsTypeDef,
    AwsEcsServicePlacementStrategiesDetailsTypeDef,
    AwsEcsServiceServiceRegistriesDetailsTypeDef,
    AwsEcsServiceNetworkConfigurationAwsVpcConfigurationDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsDependsOnDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsEnvironmentDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsEnvironmentFilesDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsExtraHostsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsFirelensConfigurationDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsHealthCheckDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsMountPointsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsPortMappingsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsRepositoryCredentialsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsResourceRequirementsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsSecretsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsSystemControlsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsUlimitsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsVolumesFromDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersCapabilitiesDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDevicesDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersTmpfsDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationSecretOptionsDetailsTypeDef,
    AwsEcsTaskDefinitionInferenceAcceleratorsDetailsTypeDef,
    AwsEcsTaskDefinitionPlacementConstraintsDetailsTypeDef,
    AwsEcsTaskDefinitionProxyConfigurationProxyConfigurationPropertiesDetailsTypeDef,
    AwsEcsTaskDefinitionVolumesDockerVolumeConfigurationDetailsTypeDef,
    AwsEcsTaskDefinitionVolumesHostDetailsTypeDef,
    AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationAuthorizationConfigDetailsTypeDef,
    AwsEcsTaskVolumeHostDetailsTypeDef,
    AwsEfsAccessPointPosixUserDetailsTypeDef,
    AwsEfsAccessPointRootDirectoryCreationInfoDetailsTypeDef,
    AwsEksClusterResourcesVpcConfigDetailsTypeDef,
    AwsEksClusterLoggingClusterLoggingDetailsTypeDef,
    AwsElasticBeanstalkEnvironmentEnvironmentLinkTypeDef,
    AwsElasticBeanstalkEnvironmentOptionSettingTypeDef,
    AwsElasticBeanstalkEnvironmentTierTypeDef,
    AwsElasticsearchDomainDomainEndpointOptionsTypeDef,
    AwsElasticsearchDomainEncryptionAtRestOptionsTypeDef,
    AwsElasticsearchDomainNodeToNodeEncryptionOptionsTypeDef,
    AwsElasticsearchDomainServiceSoftwareOptionsTypeDef,
    AwsElasticsearchDomainVPCOptionsTypeDef,
    AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetailsTypeDef,
    AwsElasticsearchDomainLogPublishingOptionsLogConfigTypeDef,
    AwsElbAppCookieStickinessPolicyTypeDef,
    AwsElbLbCookieStickinessPolicyTypeDef,
    AwsElbLoadBalancerAccessLogTypeDef,
    AwsElbLoadBalancerAdditionalAttributeTypeDef,
    AwsElbLoadBalancerConnectionDrainingTypeDef,
    AwsElbLoadBalancerConnectionSettingsTypeDef,
    AwsElbLoadBalancerCrossZoneLoadBalancingTypeDef,
    AwsElbLoadBalancerBackendServerDescriptionTypeDef,
    AwsElbLoadBalancerHealthCheckTypeDef,
    AwsElbLoadBalancerInstanceTypeDef,
    AwsElbLoadBalancerSourceSecurityGroupTypeDef,
    AwsElbLoadBalancerListenerTypeDef,
    AwsElbv2LoadBalancerAttributeTypeDef,
    LoadBalancerStateTypeDef,
    AwsIamAccessKeySessionContextAttributesTypeDef,
    AwsIamAccessKeySessionContextSessionIssuerTypeDef,
    AwsIamAttachedManagedPolicyTypeDef,
    AwsIamGroupPolicyTypeDef,
    AwsIamInstanceProfileRoleTypeDef,
    AwsIamPermissionsBoundaryTypeDef,
    AwsIamPolicyVersionTypeDef,
    AwsIamRolePolicyTypeDef,
    AwsIamUserPolicyTypeDef,
    AwsKinesisStreamStreamEncryptionDetailsTypeDef,
    AwsKmsKeyDetailsTypeDef,
    AwsLambdaFunctionCodeTypeDef,
    AwsLambdaFunctionDeadLetterConfigTypeDef,
    AwsLambdaFunctionLayerTypeDef,
    AwsLambdaFunctionTracingConfigTypeDef,
    AwsLambdaFunctionVpcConfigTypeDef,
    AwsLambdaFunctionEnvironmentErrorTypeDef,
    AwsLambdaLayerVersionDetailsTypeDef,
    AwsNetworkFirewallFirewallSubnetMappingsDetailsTypeDef,
    AwsOpenSearchServiceDomainMasterUserOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainClusterConfigZoneAwarenessConfigDetailsTypeDef,
    AwsOpenSearchServiceDomainDomainEndpointOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainEncryptionAtRestOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainNodeToNodeEncryptionOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainServiceSoftwareOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainVpcOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainLogPublishingOptionTypeDef,
    AwsRdsDbClusterAssociatedRoleTypeDef,
    AwsRdsDbClusterMemberTypeDef,
    AwsRdsDbClusterOptionGroupMembershipTypeDef,
    AwsRdsDbDomainMembershipTypeDef,
    AwsRdsDbInstanceVpcSecurityGroupTypeDef,
    AwsRdsDbClusterSnapshotDetailsTypeDef,
    AwsRdsDbInstanceAssociatedRoleTypeDef,
    AwsRdsDbInstanceEndpointTypeDef,
    AwsRdsDbOptionGroupMembershipTypeDef,
    AwsRdsDbParameterGroupTypeDef,
    AwsRdsDbProcessorFeatureTypeDef,
    AwsRdsDbStatusInfoTypeDef,
    AwsRdsPendingCloudWatchLogsExportsTypeDef,
    AwsRdsDbSecurityGroupEc2SecurityGroupTypeDef,
    AwsRdsDbSecurityGroupIpRangeTypeDef,
    AwsRdsDbSubnetGroupSubnetAvailabilityZoneTypeDef,
    AwsRdsEventSubscriptionDetailsTypeDef,
    AwsRedshiftClusterClusterNodeTypeDef,
    AwsRedshiftClusterClusterParameterStatusTypeDef,
    AwsRedshiftClusterClusterSecurityGroupTypeDef,
    AwsRedshiftClusterClusterSnapshotCopyStatusTypeDef,
    AwsRedshiftClusterDeferredMaintenanceWindowTypeDef,
    AwsRedshiftClusterElasticIpStatusTypeDef,
    AwsRedshiftClusterEndpointTypeDef,
    AwsRedshiftClusterHsmStatusTypeDef,
    AwsRedshiftClusterIamRoleTypeDef,
    AwsRedshiftClusterLoggingStatusTypeDef,
    AwsRedshiftClusterPendingModifiedValuesTypeDef,
    AwsRedshiftClusterResizeInfoTypeDef,
    AwsRedshiftClusterRestoreStatusTypeDef,
    AwsRedshiftClusterVpcSecurityGroupTypeDef,
    AwsS3AccountPublicAccessBlockDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesAbortIncompleteMultipartUploadDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesNoncurrentVersionTransitionsDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesTransitionsDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateTagDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateOperandsTagDetailsTypeDef,
    AwsS3BucketBucketVersioningConfigurationTypeDef,
    AwsS3BucketLoggingConfigurationTypeDef,
    AwsS3BucketNotificationConfigurationS3KeyFilterRuleTypeDef,
    AwsS3BucketServerSideEncryptionByDefaultTypeDef,
    AwsS3BucketWebsiteConfigurationRedirectToTypeDef,
    AwsS3BucketWebsiteConfigurationRoutingRuleConditionTypeDef,
    AwsS3BucketWebsiteConfigurationRoutingRuleRedirectTypeDef,
    AwsS3ObjectDetailsTypeDef,
    AwsSecretsManagerSecretRotationRulesTypeDef,
    BooleanFilterTypeDef,
    IpFilterTypeDef,
    KeywordFilterTypeDef,
    MapFilterTypeDef,
    NumberFilterTypeDef,
    StringFilterTypeDef,
    AwsSecurityFindingIdentifierTypeDef,
    MalwareTypeDef,
    NoteTypeDef,
    PatchSummaryTypeDef,
    ProcessDetailsTypeDef,
    RelatedFindingTypeDef,
    SeverityTypeDef,
    ThreatIntelIndicatorTypeDef,
    WorkflowTypeDef,
    AwsSnsTopicSubscriptionTypeDef,
    AwsSqsQueueDetailsTypeDef,
    AwsSsmComplianceSummaryTypeDef,
    AwsWafRateBasedRuleMatchPredicateTypeDef,
    AwsWafRegionalRateBasedRuleMatchPredicateTypeDef,
    AwsWafRegionalRulePredicateListDetailsTypeDef,
    AwsWafRegionalRuleGroupRulesActionDetailsTypeDef,
    AwsWafRegionalWebAclRulesListActionDetailsTypeDef,
    AwsWafRegionalWebAclRulesListOverrideActionDetailsTypeDef,
    AwsWafRulePredicateListDetailsTypeDef,
    AwsWafRuleGroupRulesActionDetailsTypeDef,
    WafActionTypeDef,
    WafExcludedRuleTypeDef,
    WafOverrideActionTypeDef,
    AwsXrayEncryptionConfigDetailsTypeDef,
    BatchDisableStandardsRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    StandardsSubscriptionRequestTypeDef,
    ImportFindingsErrorTypeDef,
    NoteUpdateTypeDef,
    SeverityUpdateTypeDef,
    WorkflowUpdateTypeDef,
    CellTypeDef,
    ClassificationStatusTypeDef,
    StatusReasonTypeDef,
    VolumeMountTypeDef,
    CreateActionTargetRequestRequestTypeDef,
    CreateFindingAggregatorRequestRequestTypeDef,
    ResultTypeDef,
    DateRangeTypeDef,
    DeclineInvitationsRequestRequestTypeDef,
    DeleteActionTargetRequestRequestTypeDef,
    DeleteFindingAggregatorRequestRequestTypeDef,
    DeleteInsightRequestRequestTypeDef,
    DeleteInvitationsRequestRequestTypeDef,
    DeleteMembersRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    DescribeActionTargetsRequestRequestTypeDef,
    DescribeHubRequestRequestTypeDef,
    DescribeProductsRequestRequestTypeDef,
    ProductTypeDef,
    DescribeStandardsControlsRequestRequestTypeDef,
    StandardsControlTypeDef,
    DescribeStandardsRequestRequestTypeDef,
    StandardTypeDef,
    DisableImportFindingsForProductRequestRequestTypeDef,
    DisableOrganizationAdminAccountRequestRequestTypeDef,
    DisassociateMembersRequestRequestTypeDef,
    EnableImportFindingsForProductRequestRequestTypeDef,
    EnableOrganizationAdminAccountRequestRequestTypeDef,
    EnableSecurityHubRequestRequestTypeDef,
    FilePathsTypeDef,
    FindingAggregatorTypeDef,
    FindingProviderSeverityTypeDef,
    FirewallPolicyStatefulRuleGroupReferencesDetailsTypeDef,
    FirewallPolicyStatelessRuleGroupReferencesDetailsTypeDef,
    InvitationTypeDef,
    GetEnabledStandardsRequestRequestTypeDef,
    GetFindingAggregatorRequestRequestTypeDef,
    SortCriterionTypeDef,
    GetInsightResultsRequestRequestTypeDef,
    GetInsightsRequestRequestTypeDef,
    GetMembersRequestRequestTypeDef,
    MemberTypeDef,
    InsightResultValueTypeDef,
    InviteMembersRequestRequestTypeDef,
    ListEnabledProductsForImportRequestRequestTypeDef,
    ListFindingAggregatorsRequestRequestTypeDef,
    ListInvitationsRequestRequestTypeDef,
    ListMembersRequestRequestTypeDef,
    ListOrganizationAdminAccountsRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    PortRangeTypeDef,
    RangeTypeDef,
    RecordTypeDef,
    RecommendationTypeDef,
    RuleGroupSourceListDetailsTypeDef,
    RuleGroupSourceStatefulRulesHeaderDetailsTypeDef,
    RuleGroupSourceStatefulRulesOptionsDetailsTypeDef,
    RuleGroupSourceStatelessRuleMatchAttributesDestinationPortsTypeDef,
    RuleGroupSourceStatelessRuleMatchAttributesDestinationsTypeDef,
    RuleGroupSourceStatelessRuleMatchAttributesSourcePortsTypeDef,
    RuleGroupSourceStatelessRuleMatchAttributesSourcesTypeDef,
    RuleGroupSourceStatelessRuleMatchAttributesTcpFlagsTypeDef,
    RuleGroupVariablesIpSetsDetailsTypeDef,
    RuleGroupVariablesPortSetsDetailsTypeDef,
    SoftwarePackageTypeDef,
    StandardsStatusReasonTypeDef,
    StatelessCustomPublishMetricActionDimensionTypeDef,
    TagResourceRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateActionTargetRequestRequestTypeDef,
    UpdateFindingAggregatorRequestRequestTypeDef,
    UpdateOrganizationConfigurationRequestRequestTypeDef,
    UpdateSecurityHubConfigurationRequestRequestTypeDef,
    UpdateStandardsControlRequestRequestTypeDef,
    VulnerabilityVendorTypeDef,
    CreateMembersRequestRequestTypeDef,
    ActionRemoteIpDetailsTypeDef,
    CvssTypeDef,
    AwsApiGatewayRestApiDetailsTypeDef,
    AwsApiGatewayStageDetailsTypeDef,
    AwsApiGatewayV2ApiDetailsTypeDef,
    AwsApiGatewayV2StageDetailsTypeDef,
    AwsAutoScalingAutoScalingGroupMixedInstancesPolicyLaunchTemplateDetailsTypeDef,
    AwsAutoScalingLaunchConfigurationBlockDeviceMappingsDetailsTypeDef,
    AwsBackupBackupPlanRuleCopyActionsDetailsTypeDef,
    AwsBackupBackupVaultDetailsTypeDef,
    AwsBackupRecoveryPointDetailsTypeDef,
    AwsCertificateManagerCertificateDomainValidationOptionTypeDef,
    AwsCloudFormationStackDetailsTypeDef,
    AwsCloudFrontDistributionCacheBehaviorsTypeDef,
    AwsCloudFrontDistributionOriginCustomOriginConfigTypeDef,
    AwsCloudFrontDistributionOriginGroupFailoverTypeDef,
    AwsCloudWatchAlarmDetailsTypeDef,
    AwsCodeBuildProjectEnvironmentTypeDef,
    AwsCodeBuildProjectLogsConfigDetailsTypeDef,
    AwsDynamoDbTableGlobalSecondaryIndexTypeDef,
    AwsDynamoDbTableLocalSecondaryIndexTypeDef,
    AwsDynamoDbTableReplicaGlobalSecondaryIndexTypeDef,
    AwsEc2InstanceDetailsTypeDef,
    AwsEc2NetworkAclEntryTypeDef,
    AwsEc2NetworkInterfaceDetailsTypeDef,
    AwsEc2SecurityGroupIpPermissionTypeDef,
    AwsEc2SubnetDetailsTypeDef,
    AwsEc2VolumeDetailsTypeDef,
    AwsEc2VpcDetailsTypeDef,
    AwsEc2VpcEndpointServiceDetailsTypeDef,
    AwsEc2VpcPeeringConnectionVpcInfoDetailsTypeDef,
    AwsEc2VpnConnectionOptionsDetailsTypeDef,
    AwsEcrRepositoryDetailsTypeDef,
    AwsEcsClusterConfigurationExecuteCommandConfigurationDetailsTypeDef,
    AwsEcsContainerDetailsTypeDef,
    AwsEcsServiceDeploymentConfigurationDetailsTypeDef,
    AwsEcsServiceNetworkConfigurationDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsLinuxParametersDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsLogConfigurationDetailsTypeDef,
    AwsEcsTaskDefinitionProxyConfigurationDetailsTypeDef,
    AwsEcsTaskDefinitionVolumesEfsVolumeConfigurationDetailsTypeDef,
    AwsEcsTaskVolumeDetailsTypeDef,
    AwsEfsAccessPointRootDirectoryDetailsTypeDef,
    AwsEksClusterLoggingDetailsTypeDef,
    AwsElasticBeanstalkEnvironmentDetailsTypeDef,
    AwsElasticsearchDomainElasticsearchClusterConfigDetailsTypeDef,
    AwsElasticsearchDomainLogPublishingOptionsTypeDef,
    AwsElbLoadBalancerPoliciesTypeDef,
    AwsElbLoadBalancerAttributesTypeDef,
    AwsElbLoadBalancerListenerDescriptionTypeDef,
    AwsElbv2LoadBalancerDetailsTypeDef,
    AwsIamAccessKeySessionContextTypeDef,
    AwsIamGroupDetailsTypeDef,
    AwsIamInstanceProfileTypeDef,
    AwsIamPolicyDetailsTypeDef,
    AwsIamUserDetailsTypeDef,
    AwsKinesisStreamDetailsTypeDef,
    AwsLambdaFunctionEnvironmentTypeDef,
    AwsNetworkFirewallFirewallDetailsTypeDef,
    AwsOpenSearchServiceDomainAdvancedSecurityOptionsDetailsTypeDef,
    AwsOpenSearchServiceDomainClusterConfigDetailsTypeDef,
    AwsOpenSearchServiceDomainLogPublishingOptionsDetailsTypeDef,
    AwsRdsDbClusterDetailsTypeDef,
    AwsRdsDbSnapshotDetailsTypeDef,
    AwsRdsDbPendingModifiedValuesTypeDef,
    AwsRdsDbSecurityGroupDetailsTypeDef,
    AwsRdsDbSubnetGroupSubnetTypeDef,
    AwsRedshiftClusterClusterParameterGroupTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateOperandsDetailsTypeDef,
    AwsS3BucketNotificationConfigurationS3KeyFilterTypeDef,
    AwsS3BucketServerSideEncryptionRuleTypeDef,
    AwsS3BucketWebsiteConfigurationRoutingRuleTypeDef,
    AwsSecretsManagerSecretDetailsTypeDef,
    BatchUpdateFindingsUnprocessedFindingTypeDef,
    AwsSnsTopicDetailsTypeDef,
    AwsSsmPatchTypeDef,
    AwsWafRateBasedRuleDetailsTypeDef,
    AwsWafRegionalRateBasedRuleDetailsTypeDef,
    AwsWafRegionalRuleDetailsTypeDef,
    AwsWafRegionalRuleGroupRulesDetailsTypeDef,
    AwsWafRegionalWebAclRulesListDetailsTypeDef,
    AwsWafRuleDetailsTypeDef,
    AwsWafRuleGroupRulesDetailsTypeDef,
    AwsWafWebAclRuleTypeDef,
    CreateActionTargetResponseTypeDef,
    CreateFindingAggregatorResponseTypeDef,
    CreateInsightResponseTypeDef,
    DeleteActionTargetResponseTypeDef,
    DeleteInsightResponseTypeDef,
    DescribeActionTargetsResponseTypeDef,
    DescribeHubResponseTypeDef,
    DescribeOrganizationConfigurationResponseTypeDef,
    EnableImportFindingsForProductResponseTypeDef,
    GetFindingAggregatorResponseTypeDef,
    GetInvitationsCountResponseTypeDef,
    ListEnabledProductsForImportResponseTypeDef,
    ListOrganizationAdminAccountsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    UpdateFindingAggregatorResponseTypeDef,
    BatchEnableStandardsRequestRequestTypeDef,
    BatchImportFindingsResponseTypeDef,
    BatchUpdateFindingsRequestRequestTypeDef,
    ComplianceTypeDef,
    ContainerDetailsTypeDef,
    CreateMembersResponseTypeDef,
    DeclineInvitationsResponseTypeDef,
    DeleteInvitationsResponseTypeDef,
    DeleteMembersResponseTypeDef,
    InviteMembersResponseTypeDef,
    DateFilterTypeDef,
    DescribeActionTargetsRequestDescribeActionTargetsPaginateTypeDef,
    DescribeProductsRequestDescribeProductsPaginateTypeDef,
    DescribeStandardsControlsRequestDescribeStandardsControlsPaginateTypeDef,
    DescribeStandardsRequestDescribeStandardsPaginateTypeDef,
    GetEnabledStandardsRequestGetEnabledStandardsPaginateTypeDef,
    GetInsightsRequestGetInsightsPaginateTypeDef,
    ListEnabledProductsForImportRequestListEnabledProductsForImportPaginateTypeDef,
    ListFindingAggregatorsRequestListFindingAggregatorsPaginateTypeDef,
    ListInvitationsRequestListInvitationsPaginateTypeDef,
    ListMembersRequestListMembersPaginateTypeDef,
    ListOrganizationAdminAccountsRequestListOrganizationAdminAccountsPaginateTypeDef,
    DescribeProductsResponseTypeDef,
    DescribeStandardsControlsResponseTypeDef,
    DescribeStandardsResponseTypeDef,
    ThreatTypeDef,
    ListFindingAggregatorsResponseTypeDef,
    FindingProviderFieldsTypeDef,
    GetAdministratorAccountResponseTypeDef,
    GetMasterAccountResponseTypeDef,
    ListInvitationsResponseTypeDef,
    GetMembersResponseTypeDef,
    ListMembersResponseTypeDef,
    InsightResultsTypeDef,
    NetworkPathComponentDetailsTypeDef,
    NetworkTypeDef,
    PageTypeDef,
    RemediationTypeDef,
    RuleGroupSourceStatefulRulesDetailsTypeDef,
    RuleGroupSourceStatelessRuleMatchAttributesTypeDef,
    RuleGroupVariablesTypeDef,
    StandardsSubscriptionTypeDef,
    StatelessCustomPublishMetricActionTypeDef,
    AwsApiCallActionTypeDef,
    NetworkConnectionActionTypeDef,
    PortProbeDetailTypeDef,
    VulnerabilityTypeDef,
    AwsAutoScalingAutoScalingGroupMixedInstancesPolicyDetailsTypeDef,
    AwsAutoScalingLaunchConfigurationDetailsTypeDef,
    AwsBackupBackupPlanRuleDetailsTypeDef,
    AwsCertificateManagerCertificateRenewalSummaryTypeDef,
    AwsCloudFrontDistributionOriginItemTypeDef,
    AwsCloudFrontDistributionOriginGroupTypeDef,
    AwsCodeBuildProjectDetailsTypeDef,
    AwsDynamoDbTableReplicaTypeDef,
    AwsEc2NetworkAclDetailsTypeDef,
    AwsEc2SecurityGroupDetailsTypeDef,
    AwsEc2VpcPeeringConnectionDetailsTypeDef,
    AwsEc2VpnConnectionDetailsTypeDef,
    AwsEcsClusterConfigurationDetailsTypeDef,
    AwsEcsServiceDetailsTypeDef,
    AwsEcsTaskDefinitionContainerDefinitionsDetailsTypeDef,
    AwsEcsTaskDefinitionVolumesDetailsTypeDef,
    AwsEcsTaskDetailsTypeDef,
    AwsEfsAccessPointDetailsTypeDef,
    AwsEksClusterDetailsTypeDef,
    AwsElasticsearchDomainDetailsTypeDef,
    AwsElbLoadBalancerDetailsTypeDef,
    AwsIamAccessKeyDetailsTypeDef,
    AwsIamRoleDetailsTypeDef,
    AwsLambdaFunctionDetailsTypeDef,
    AwsOpenSearchServiceDomainDetailsTypeDef,
    AwsRdsDbSubnetGroupTypeDef,
    AwsRedshiftClusterDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesFilterPredicateDetailsTypeDef,
    AwsS3BucketNotificationConfigurationFilterTypeDef,
    AwsS3BucketServerSideEncryptionConfigurationTypeDef,
    AwsS3BucketWebsiteConfigurationTypeDef,
    BatchUpdateFindingsResponseTypeDef,
    AwsSsmPatchComplianceDetailsTypeDef,
    AwsWafRegionalRuleGroupDetailsTypeDef,
    AwsWafRegionalWebAclDetailsTypeDef,
    AwsWafRuleGroupDetailsTypeDef,
    AwsWafWebAclDetailsTypeDef,
    AwsSecurityFindingFiltersTypeDef,
    GetInsightResultsResponseTypeDef,
    NetworkHeaderTypeDef,
    OccurrencesTypeDef,
    RuleGroupSourceStatelessRuleDefinitionTypeDef,
    BatchDisableStandardsResponseTypeDef,
    BatchEnableStandardsResponseTypeDef,
    GetEnabledStandardsResponseTypeDef,
    StatelessCustomActionDefinitionTypeDef,
    PortProbeActionTypeDef,
    AwsAutoScalingAutoScalingGroupDetailsTypeDef,
    AwsBackupBackupPlanBackupPlanDetailsTypeDef,
    AwsCertificateManagerCertificateDetailsTypeDef,
    AwsCloudFrontDistributionOriginsTypeDef,
    AwsCloudFrontDistributionOriginGroupsTypeDef,
    AwsDynamoDbTableDetailsTypeDef,
    AwsEcsClusterDetailsTypeDef,
    AwsEcsTaskDefinitionDetailsTypeDef,
    AwsRdsDbInstanceDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesFilterDetailsTypeDef,
    AwsS3BucketNotificationConfigurationDetailTypeDef,
    CreateInsightRequestRequestTypeDef,
    GetFindingsRequestGetFindingsPaginateTypeDef,
    GetFindingsRequestRequestTypeDef,
    InsightTypeDef,
    UpdateFindingsRequestRequestTypeDef,
    UpdateInsightRequestRequestTypeDef,
    NetworkPathComponentTypeDef,
    CustomDataIdentifiersDetectionsTypeDef,
    SensitiveDataDetectionsTypeDef,
    RuleGroupSourceStatelessRulesDetailsTypeDef,
    FirewallPolicyStatelessCustomActionsDetailsTypeDef,
    RuleGroupSourceCustomActionsDetailsTypeDef,
    ActionTypeDef,
    AwsBackupBackupPlanDetailsTypeDef,
    AwsCloudFrontDistributionDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationRulesDetailsTypeDef,
    AwsS3BucketNotificationConfigurationTypeDef,
    GetInsightsResponseTypeDef,
    CustomDataIdentifiersResultTypeDef,
    SensitiveDataResultTypeDef,
    FirewallPolicyDetailsTypeDef,
    RuleGroupSourceStatelessRulesAndCustomActionsDetailsTypeDef,
    AwsS3BucketBucketLifecycleConfigurationDetailsTypeDef,
    ClassificationResultTypeDef,
    AwsNetworkFirewallFirewallPolicyDetailsTypeDef,
    RuleGroupSourceTypeDef,
    AwsS3BucketDetailsTypeDef,
    DataClassificationDetailsTypeDef,
    RuleGroupDetailsTypeDef,
    AwsNetworkFirewallRuleGroupDetailsTypeDef,
    ResourceDetailsTypeDef,
    ResourceTypeDef,
    AwsSecurityFindingTypeDef,
    BatchImportFindingsRequestRequestTypeDef,
    GetFindingsResponseTypeDef,
)


def get_structure() -> AcceptAdministratorInvitationRequestRequestTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-securityhub` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securityhub/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
